@@ -78,7 +78,7 @@ def bands_list(elements, elements_exclusive, raw, formula_mode, past_days, group
         echo.echo(tabulate(bands_list_data, tablefmt='plain'))
     else:
         echo.echo(tabulate(bands_list_data, headers='firstrow'))
-        echo.echo('\nTotal results: {}\n'.format(counter))
+        echo.echo(f'\nTotal results: {counter}\n')
 
 
 @bands.command('show')
@@ -88,9 +88,9 @@ def bands_list(elements, elements_exclusive, raw, formula_mode, past_days, group
 def bands_show(data, fmt):
     """Visualize BandsData objects."""
     try:
-        show_function = getattr(cmd_show, '_show_{}'.format(fmt))
+        show_function = getattr(cmd_show, f'_show_{fmt}')
     except AttributeError:
-        echo.echo_critical('visualization format {} is not supported'.format(fmt))
+        echo.echo_critical(f'visualization format {fmt} is not supported')
 
     show_function(fmt, data)
 
